#

##

    	vocab
    		# legend
    		# no plagiarism
    		# nomenclature

    	entries

    		key:
    			# openers
    			# ships
    			# alias
    			# identity
    			# aura
    			# essence
    			# sequence
    			# vibe
    			# curve, key, combo
    			# trends

    		elliptic keys
    			# elliptic vibes

    		private keys
    			# implicit
    				# subconscious

    			# essence

    		public keys
    			# explicit
    				# conscious

    			# name
    			# address
    			# popularity
    				# fame

    		signing
    			# stamping
    			# abstracting
    			# performing

    		signature
    			# abstraction
    			# insignia
    			# crest
    			# emblem
    			# badge

    		verifying
    			# endorsing
    			# approve
    			# endorse
    			# prove
    			# approve
    			# authenticators